@@ -228,6 +228,8 @@ class FootPrint(BaseModelTimeAndDeleted):
     order_number = models.CharField('Order Number', max_length=128, blank=True, null=True)
     # event(事件)
     event = models.CharField('事件', max_length=128, blank=True, null=True, db_index=True)
+    # event_remarks(事件备注)
+    event_remarks = models.CharField('事件备注', max_length=36, blank=True, null=True)
     # event_sponsor（事件发起人）
     event_sponsor = models.CharField('事件发起人', max_length=255, blank=True, null=True)
     # event_sponsor_name（事件发起人昵称）
